#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_EXPONENTBITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_EXPONENTBITS_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/exponentbits.hpp>

#endif
